/*
 * Copyright (c) 2017-2024, Lawrence Livermore National Security, LLC and
 * other Axom Project Developers. See the top-level LICENSE file for details.
 *
 * SPDX-License-Identifier: (BSD-3-Clause)
 */

#ifndef AXOM_COMMON_CONFIG_HPP
#define AXOM_COMMON_CONFIG_HPP

/*
 * Note: Use only C-style comments in this file
 *       since it might be included from a C file
 */

/*
 * Axom Version Information
 */
#define AXOM_VERSION_MAJOR 0
#define AXOM_VERSION_MINOR 10
#define AXOM_VERSION_PATCH 1
#define AXOM_VERSION_FULL "v0.10.1"
/*NOTE: Do not add AXOM_GIT_SHA here.  This will force
 * full rebuild on all local changes. It is added in axom::getVersion()
 * and axom::about(), as well as accessible from axom::gitSha().
 */

/*
 * Axom source location
 */
#define AXOM_SRC_DIR "/wrkdirs/usr/ports/science/axom/work/axom-0.10.1/src"
#define AXOM_BIN_DIR "/wrkdirs/usr/ports/science/axom/work/.build"
#define AXOM_DATA_DIR "/wrkdirs/usr/ports/science/axom/work/axom-0.10.1/data"

/*
 * Platform specific definitions
 */
#define AXOM_CXX_STD "c++14"
/* #undef AXOM_CUDA_ARCH */
/* #undef AXOM_NO_INT64_T */

#ifndef AXOM_NO_INT64_T
/* #undef AXOM_USE_64BIT_INDEXTYPE */
#endif

/*
 * Compiler tests
 */
/* #undef USE_C_LOC_WITH_ASSUMED_SHAPE */

/*
 * Compiler defines for programming models
 */
/* #undef AXOM_USE_CUDA */
/* #undef AXOM_USE_HIP */
#define AXOM_USE_MPI
/* #undef AXOM_USE_MPI3 */
/* #undef AXOM_USE_MPIF_HEADER */
/* #undef AXOM_USE_OPENMP */

/*
 * Compiler defines for libraries (built-in and third party)
 */
/* #undef AXOM_USE_ADIAK */
/* #undef AXOM_USE_C2C */
/* #undef AXOM_USE_CALIPER */
#define AXOM_USE_CLI11
#define AXOM_USE_CONDUIT
#define AXOM_USE_FMT
#define AXOM_USE_HDF5
#define AXOM_USE_LUA
#define AXOM_USE_MFEM
/* #undef AXOM_USE_RAJA */
/* #undef AXOM_USE_SCR */
#define AXOM_USE_SOL
#define AXOM_USE_SPARSEHASH
/* #undef AXOM_USE_UMPIRE */

/*
 * Compiler defines for third-party executables
 */
/* #undef JSONSCHEMA_EXECUTABLE */

/*
 * We need to explicitly add some definitions on Windows
 * for math defines (_USE_MATH_DEFINES), and to disambiguate
 * Windows GDI geometry classes (NOGDI).
 */
#ifdef WIN32
#define _USE_MATH_DEFINES
#define NOGDI
#define NOMINMAX
#endif

/*
 * Compiler defines for Axom components
 */
#define AXOM_USE_INLET
#define AXOM_USE_KLEE
#define AXOM_USE_LUMBERJACK
#define AXOM_USE_MINT
#define AXOM_USE_PRIMAL
#define AXOM_USE_QUEST
#define AXOM_USE_SIDRE
#define AXOM_USE_SLAM
#define AXOM_USE_SLIC
#define AXOM_USE_SPIN

/*
 * For gradual removal of types that have been deprecated in favor of
 * c++-11 types.  Value can be 1 to allow with compiler warnings, 2 to
 * allow silently, and -1 to disallow.  Corresponds to cmake variable
 * AXOM_DEPRECATED_TYPES values of WARN, ALLOW and ERROR.
 */
/* #undef AXOM_DEPRECATED_TYPES_N */

/*
 * Compiler defines to configure the built-in fmt library
 */
#define AXOM_FMT_EXCEPTIONS 0
#define AXOM_FMT_HEADER_ONLY 1

/*
 * Compiler defines to configure the built-in sparsehash library
 */
#define SPARSEHASH_HASHFUN_HEADER <functional>
#define SPARSEHASH_HASHFUN_NAMESPACE std

/*
 * Disable some MSVC warnings related to shared libraries, if applicable
 */


#endif /* AXOM_COMMON_CONFIG_HPP */
